@@ -10,7 +10,7 @@
 """
 from __future__ import with_statement
 
-__version__ = '0.7.2'
+__version__ = '0.7.3'
 
 import blinker
 import smtplib
@@ -158,6 +158,7 @@ class Message(object):
     :param reply_to: reply-to address
     :param date: send date
     :param charset: message character set
+    :param extra_headers: A dictionary of additional headers for the message
     """
 
     def __init__(self, subject,
@@ -170,7 +171,8 @@ class Message(object):
                  attachments=None,
                  reply_to=None,
                  date=None,
-                 charset=None):
+                 charset=None,
+                 extra_headers=None):
 
         if sender is None:
             sender = current_app.config.get("DEFAULT_MAIL_SENDER")
@@ -186,6 +188,7 @@ class Message(object):
         self.date = date
         self.msgId = make_msgid()
         self.charset = charset
+        self.extra_headers = extra_headers
 
         self.cc = cc
         self.bcc = bcc
@@ -248,6 +251,10 @@ class Message(object):
         if self.reply_to:
             msg['Reply-To'] = self.reply_to
 
+        if self.extra_headers:
+            for k, v in self.extra_headers.iteritems():
+                msg[k] = v
+
         for attachment in self.attachments:
             f = MIMEBase(*attachment.content_type.split('/'))
             f.set_payload(attachment.data)
